package App::rank;

our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Rank lines of text files

__END__

=pod

=encoding UTF-8

=head1 NAME

App::rank - Rank lines of text files

=head1 VERSION

This document describes version 0.003 of App::rank (from Perl distribution App-rank), released on 2018-04-22.

=head1 SYNOPSIS

See the command-line script L<rank>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-rank>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-rank>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-rank>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<List::Rank>, L<Sort::Rank>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
